# Generated by roxygen2: do not edit by hand

S3method(print,latent_comparison)
S3method(print,modelscompete4)
S3method(print,modelscompete4_advanced)
export(bootstrap_lavaan_comparison)
export(compare_latent_models)
export(compare_models)
export(compare_models_advanced_lv)
export(extract_latent_fit)
export(extract_latent_parameters)
export(plot_latent_comparison)
importFrom(boot,boot)
importFrom(boot,boot.ci)
importFrom(lavaan,cfa)
importFrom(lavaan,fitMeasures)
importFrom(lavaan,lavInspect)
importFrom(lavaan,lavTestLRT)
importFrom(lavaan,parameterEstimates)
importFrom(lavaan,sem)
importFrom(lavaan,standardizedSolution)
importFrom(nonnest2,vuongtest)
importFrom(stats,AIC)
importFrom(stats,BIC)
importFrom(stats,logLik)
importFrom(stats,quantile)
importFrom(stats,residuals)
importFrom(stats,sd)
importFrom(stats,update)
importFrom(utils,head)
importFrom(utils,packageVersion)
importFrom(utils,str)
importFrom(utils,tail)
