% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{format_ci}
\alias{format_ci}
\title{Format confidence intervals}
\usage{
format_ci(lower, upper, digits = 3)
}
\arguments{
\item{lower}{Lower bound of CI}

\item{upper}{Upper bound of CI}

\item{digits}{Number of decimal places (default=3)}
}
\value{
Formatted CI string
}
\description{
This function formats confidence intervals into a readable string.
}
\keyword{internal}
